# Topsis-Shanya-101953017

This package is implementation of topsis technique of multi-criteria decision analysis. This package will accept three parameters as input:


1. .csv file which contains the models and parameters
2. string of weights separated by commas(,)
3. string of requirements (+/-) separated by commas(,) 


### What is TOPSIS
The Technique for Order of Preference by Similarity to Ideal Solution
(TOPSIS) is a multi-criteria decision analysis method.
TOPSIS is based on the concept that the chosen alternative should have the shortest geometric distance from the positive ideal solution (PIS)
and the longest geometric distance from the negative ideal solution (NIS).
### Installation 
To install this module write the following line in the command prompt.

pip install Topsis-Shanya-101953017
### How to use this 

Topsis-Shanya-101953017 can be run as in the following example:

####In Command Prompt

 >> topsis data.csv "1,1,1,1" "+,+,-,+"



###License

© 2021 Shanya

This repository is licensed under the MIT license. See LICENSE for details